@@ -2,7 +2,7 @@ package ExtUtils::ModuleMaker;
 use strict;
 local $^W = 1;
 use vars qw ($VERSION);
-$VERSION = 0.34;
+$VERSION = 0.35;
 
 use ExtUtils::ModuleMaker::Licenses::Standard;
 use ExtUtils::ModuleMaker::Licenses::Local;
@@ -22,29 +22,18 @@ sub new {
         if (@arglist % 2);
     my %parameters = @arglist;
     my @badkeys;
-    my %keys_permitted = map {$_, 1} qw|
-        NAME
-        ABSTRACT
-        VERSION
-        LICENSE
-        BUILD_SYSTEM
-        AUTHOR
-        EXTRA_MODULES
-        COMPACT
-        VERBOSE
-        INTERACTIVE
-        PERMISSIONS
-        USAGE_MESSAGE
-        NEED_POD
-        NEED_NEW_METHOD
-        CHANGES_IN_POD
+    my %keys_forbidden = map {$_, 1} qw|
+        CPANID
+        ORGANIZATION
+        WEBSITE
+        EMAIL
     |;
-    
     for (keys %parameters) {
-        push(@badkeys, $_) unless $keys_permitted{$_};
+        push(@badkeys, $_) if $keys_forbidden{$_};
     }
-    croak "Dying due to bad input to constructor (@badkeys): $!"
+    croak "@badkeys improper top-level key: $!"
         if (@badkeys);
+
     my $self = ref($class) ? bless( default_values(), ref($class) )
                            : bless( default_values(), $class );
     foreach my $param ( keys %parameters ) {
@@ -58,6 +47,7 @@ sub new {
         }
     }
 
+#    if ($self->{INTERACTIVE}) { print STDERR "Get data interactively!\n"; }
     $self->set_author_data();
     $self->set_dates();
     $self->initialize_license();
@@ -171,6 +161,8 @@ sub verify_values {
 
     push( @errors, 'NAME is required' )
       unless ( $self->{NAME} );
+    push( @errors, 'Module NAME contains illegal characters' )
+      unless ( $self->{NAME} and $self->{NAME} =~ m/^[\w:]+$/ );
     push( @errors, 'ABSTRACTs are limited to 44 characters' )
       if ( length( $self->{ABSTRACT} ) > 44 );
     push( @errors, 'CPAN IDs are 3-9 characters' )
@@ -194,37 +186,43 @@ sub generate_pm_file {
 
     $self->create_pm_basics($module);
 
-    my $page = $self->block_begin($module) .
-
-      (
-        ( $self->module_value( $module, 'NEED_POD' ) )
-        ? $self->block_module_header($module)
-        : ()
-      )
-      .
-
-      (
-        (
-                 ( $self->module_value( $module, 'NEED_POD' ) )
-              && ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
-        )
-        ? $self->block_subroutine_header($module)
-        : ()
-      )
-      .
-
-      (
-        ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
-        ? $self->block_new_method($module)
-        : ()
-      )
-      .
-
-      $self->block_final_one($module);
+    my $page = $self->build_page($module);
 
     $self->print_file( $module->{FILE}, $page );
 }
 
+sub build_page {
+    my $self = shift;
+    my $module = shift;
+      
+    my $page = $self->block_begin($module);
+    $page .= (
+         ( $self->module_value( $module, 'NEED_POD' ) )
+         ? $self->block_module_header($module)
+         : ''
+    );
+
+    $page .= (
+         (
+            (
+                 ( $self->module_value( $module, 'NEED_POD' ) )
+              && ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
+            )
+            ? $self->block_subroutine_header($module)
+         : ''
+	 )
+    );
+
+    $page .= (
+        ( $self->module_value( $module, 'NEED_NEW_METHOD' ) )
+        ? $self->block_new_method($module)
+         : ''
+    );
+
+    $page .= $self->block_final_one($module);
+    return ($module, $page);
+}
+
 #!#!#!#!#
 ##  10 ##
 sub set_dates {
@@ -239,14 +237,14 @@ sub set_dates {
 sub set_author_data {
     my $self = shift;
 
-    my $p_author = $self->{AUTHOR};
-    $p_author->{COMPOSITE} = (
+    $self->{AUTHOR}->{COMPOSITE} = (
         "\t"
          . join( "\n\t",
-            $p_author->{NAME},
-            ( $p_author->{CPANID} ) ? "CPAN ID: $p_author->{CPANID}" : (),
-            ( $p_author->{ORGANIZATION} ) ? "$p_author->{ORGANIZATION}" : (),
-            $p_author->{EMAIL}, $p_author->{WEBSITE}, ),
+            $self->{AUTHOR}->{NAME},
+            "CPAN ID: $self->{AUTHOR}->{CPANID}", # will need to be modified
+            $self->{AUTHOR}->{ORGANIZATION},  # if defaults no longer provided
+            $self->{AUTHOR}->{EMAIL}, 
+	    $self->{AUTHOR}->{WEBSITE}, ),
     );
 }
 
@@ -262,7 +260,7 @@ sub create_base_directory {
     my $self = shift;
 
     $self->{Base_Dir} =
-      join( ( $self->{COMPACT} ) ? '-' : '/', split( /::|'/, $self->{NAME} ) );
+      join( ( $self->{COMPACT} ) ? '-' : '/', split( /::/, $self->{NAME} ) );
     $self->check_dir( $self->{Base_Dir} );
 }
 
@@ -270,7 +268,7 @@ sub create_base_directory {
 ##  14 ##
 sub create_pm_basics {
     my ( $self, $module ) = @_;
-    my @layers = split( /::|'/, $module->{NAME} );
+    my @layers = split( /::/, $module->{NAME} );
     my $file   = pop(@layers);
     my $dir    = join( '/', 'lib', @layers );
 
@@ -362,8 +360,13 @@ sub death_message {
     my %err = map {$_, 1} @errors;
     delete $err{'NAME is required'} if $err{'NAME is required'};
     @errors = keys %err;
-    print( join "\n", 'Oops, there are the following errors:', @errors, '', '' )
-        if @errors;
+    if (@errors) {
+        print( join "\n", 
+            'Oops, there are the following errors:', @errors, '' );
+        return 1;
+    } else {
+        return (); # because verify_values() returns empty list if AOK
+    }
 }
 
 #!#!#!#!#
@@ -583,7 +586,6 @@ sub block_final_one {
     my $string = <<EOFBLOCK;
 
 1; #this line is important and will help the module return a true value
-__END__
 
 EOFBLOCK
 
@@ -867,8 +869,19 @@ EOF
     return ($page);
 }
 
+sub partial_dump {
+    my $self = shift;
+    my %keys_not_shown = map {$_, 1} @_;
+    require Data::Dumper;
+    my ($k, $v, %retry);
+    while ( ($k, $v) = each %{$self} ) {
+        $retry{$k} = $v unless $keys_not_shown{$k};
+    }
+    my $d = Data::Dumper->new( [\%retry] );
+    return $d->Dump;
+}
+
 1;    #this line is important and will help the module return a true value
-__END__
 
 #################### DOCUMENTATION ####################
 
@@ -888,6 +901,11 @@ ExtUtils::ModuleMaker - Better than h2xs for creating modules
     );
     $mod->complete_build();
 
+=head1 VERSION
+
+This document references version 0.35 of ExtUtils::ModuleMaker, released
+to CPAN on July 17, 2005.
+
 =head1 DESCRIPTION
 
 This module is a replacement for the most typical use of the F<h2xs> 
@@ -925,10 +943,12 @@ F<modulemaker> bundled with this distribution.
 
 =head2 Usage within a Perl script
 
+=head3 Public Methods
+
 In this version of ExtUtils::ModuleMaker there are only two publicly 
 callable functions.  These are how you should interact with this module.
 
-=head3 C<new>
+=head4 C<new>
 
 Creates and returns an ExtUtils::ModuleMaker object.  Takes a list 
 containing key-value pairs with information specifying the
@@ -942,12 +962,9 @@ is probably best held in a hash.   Keys which may be specified are:
 =item * NAME
 
 The I<only> required feature.  This is the name of the primary module 
-(with 'C<::>' separators if needed).  Will also support the older style 
-separator ''C<'>'' like the module F<D'Oh>, though this feature is
-deprecated and is subject to removal in a future version.  In any event,
-if the module name contains an apostrophe, then the value corresponding
-to key <NAME> in the list passed must be double-quoted; otherwise
-F<Makefile.PL> gets messed up.  There is no current default for NAME.
+(with 'C<::>' separators if needed).  Will no longer support the older,
+Perl 4-style separator ''C<'>'' like the module F<D'Oh>.  There is no 
+current default for NAME.
 
 =item * ABSTRACT
 
@@ -1096,14 +1113,56 @@ Don't include a 'Changes' file, but instead add a HISTORY section to the POD.
 
 =back
 
-=head3 C<complete_build>
+=head4 C<complete_build>
 
 Creates all directories and files as configured by the key-value pairs
 passed to C<ExtUtils::ModuleMaker::new>.  Returns a
 true value if all specified files are created -- but this says nothing
 about whether those files have been created with the correct content.
 
-=head1 AUTHOR
+=head3 Private Methods
+
+There are a variety of other ExtUtil::ModuleMaker methods which are not
+currently in the public interface.  They are available for you to hack
+on, but, as they are primarily used within C<new()> and
+C<complete_build()>, their implementation and interface may change in
+the future.  See the code for inline documentation.
+
+=head1 CAVEATS
+
+=over 4
+
+=item * Tests Require Perl 5.6
+
+While the maintainer has attempted to make the code in
+F<lib/ExtUtils/Modulemaker.pm> and the F<modulemaker> utility compatible
+with versions of Perl older than 5.6, the test suite currently requires
+5.6 or later.  Eventually, we'll put those tests which absolutely
+require 5.6 or later into SKIP blocks so that the tests will run cleanly
+on 5.4 or 5.5.
+
+=item * Testing of F<modulemaker>'s Interactive Mode
+
+The easiest, laziest and recommended way of using this distribution is
+the command-line utility F<modulemaker>, especially its interactive
+mode.  However, this is necessarily the most difficult test, as its
+testing would require capturing the STDIN, STDOUT and STDERR for a
+process spawned by a C<system('modulemaker')> call from within a test
+file.  For now, the maintainer has relied on repeated visual inspection
+of the screen prompts generated by F<modulemaker>.
+
+=item * Testing F<modulemaker> on Non-*nix-Like Operating Systems
+
+Since testing the F<modulemaker> utility from within the test suite
+requires a C<system()> call, a clean test run depends in part on the way
+a given operating system parses command-line arguments.  The maintainer
+has tested this on Darwin and Win32 and, thanks to a suggestion by A.
+Sinan Unur, solved a problem on Win32.  Results on other operating
+systems may differ; feedback is welcome.
+
+=back
+
+=head1 AUTHOR/MAINTAINER
 
 ExtUtils::ModuleMaker was originally written in 2001-02 by R. Geoffrey Avery
 (modulemaker [at] PlatypiVentures [dot] com).  Since version 0.33 (July
@@ -1119,11 +1178,14 @@ in the subject line.
 
 Thanks to Geoff Avery for inventing and popularizing
 ExtUtils::Modulemaker.  Thanks for bug reports and fixes to David A
-Golden and an anonymous guest on rt.cpan.org.
+Golden and an anonymous guest on rt.cpan.org.  Thanks for suggestions
+about testing the F<modulemaker> utility to Michael G Schwern on perl.qa
+and A Sinan Unur and Paul Lalli on comp.lang.perl.misc.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2002 R. Geoffrey Avery. All rights reserved.
+Copyright (c) 2001-2002 R. Geoffrey Avery.
+Revisions from v0.33 forward (c) 2005 James E. Keenan.  All rights reserved.
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
 
